@@ -1,13 +1,16 @@
-from django.core.management.base import BaseCommand
-from django.contrib.auth import get_user_model
-
 """
-    A command for marking users as staff.
+A command for marking users as staff.
+
+::
 
     ./manage.py set_staff --field email --users me@website.com you@website.com
     ./manage.py set_staff --int --users 1 2 5
+    ./manage.py set_staff --int --unset --users 1 2 5
 """
 
+from django.core.management.base import BaseCommand
+from django.contrib.auth import get_user_model
+
 
 class Command(BaseCommand):
     def add_arguments(self, parser):
